@@ -6,8 +6,8 @@
 ;; Author: Shen, Jen-Chieh <jcs090218@gmail.com>
 ;;         Peter Oliver <git@mavit.org.uk>
 ;; URL: https://github.com/emacs-languagetool/flycheck-languagetool
-;; Package-Version: 20260101.535
-;; Package-Revision: 8889414ec50c
+;; Package-Version: 20260218.1520
+;; Package-Revision: 59dc7467425b
 ;; Package-Requires: ((emacs "27.1") (flycheck "0.14"))
 ;; Keywords: convenience grammar check
 
@@ -216,21 +216,25 @@ CALLBACK is passed from Flycheck."
                                  (goto-char (+ 1 url-http-end-of-headers))
                                  (buffer-substring (point) (point-max))))))))))
 
-  (set-buffer-multibyte t)
-  (goto-char url-http-end-of-headers)
-  (let ((results (car (flycheck-parse-json
-                       (buffer-substring (point) (point-max))))))
+  (if (buffer-live-p source-buffer)
+      (progn
+        (set-buffer-multibyte t)
+        (goto-char url-http-end-of-headers)
+        (let ((results (car (flycheck-parse-json
+                             (buffer-substring (point) (point-max))))))
+          (kill-buffer)
+          (with-current-buffer source-buffer
+            (funcall
+             callback 'finished
+             (flycheck-increment-error-columns
+              (mapcar
+               (lambda (x)
+                 (apply #'flycheck-error-new-at `(,@x :checker languagetool)))
+               (condition-case err
+                   (flycheck-languagetool--check-all results)
+                 (error (funcall callback 'errored (error-message-string err))))))))))
     (kill-buffer)
-    (with-current-buffer source-buffer
-      (funcall
-       callback 'finished
-       (flycheck-increment-error-columns
-        (mapcar
-         (lambda (x)
-           (apply #'flycheck-error-new-at `(,@x :checker languagetool)))
-         (condition-case err
-             (flycheck-languagetool--check-all results)
-           (error (funcall callback 'errored (error-message-string err))))))))))
+    (funcall callback 'interrupted nil)))
 
 (defun flycheck-languagetool--start-server ()
   "Start the LanguageTool server if we didn’t already."
@@ -271,7 +275,7 @@ CALLBACK is passed from Flycheck."
                                    (bound-and-true-p jinx-mode))
                            flycheck-languagetool--spelling-rules))))
          (other-params (assoc-delete-all "disabledRules"
-                                         flycheck-languagetool-check-params))
+                                         (copy-alist flycheck-languagetool-check-params)))
          (url-request-data
           (mapconcat
            (lambda (param)
